Class: Aws::SSMContacts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SSMContacts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ssmcontacts/client.rb,
sig/client.rbs
Overview
An API client for SSMContacts. To construct a client, you need to configure a :region and :credentials.
client = Aws::SSMContacts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptPageResponseSuccess, _ActivateContactChannelResponseSuccess, _CreateContactChannelResponseSuccess, _CreateContactResponseSuccess, _CreateRotationOverrideResponseSuccess, _CreateRotationResponseSuccess, _DeactivateContactChannelResponseSuccess, _DeleteContactChannelResponseSuccess, _DeleteContactResponseSuccess, _DeleteRotationOverrideResponseSuccess, _DeleteRotationResponseSuccess, _DescribeEngagementResponseSuccess, _DescribePageResponseSuccess, _GetContactChannelResponseSuccess, _GetContactPolicyResponseSuccess, _GetContactResponseSuccess, _GetRotationOverrideResponseSuccess, _GetRotationResponseSuccess, _ListContactChannelsResponseSuccess, _ListContactsResponseSuccess, _ListEngagementsResponseSuccess, _ListPageReceiptsResponseSuccess, _ListPageResolutionsResponseSuccess, _ListPagesByContactResponseSuccess, _ListPagesByEngagementResponseSuccess, _ListPreviewRotationShiftsResponseSuccess, _ListRotationOverridesResponseSuccess, _ListRotationShiftsResponseSuccess, _ListRotationsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutContactPolicyResponseSuccess, _SendActivationCodeResponseSuccess, _StartEngagementResponseSuccess, _StopEngagementResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateContactChannelResponseSuccess, _UpdateContactResponseSuccess, _UpdateRotationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_page(params = {}) ⇒ Struct
Used to acknowledge an engagement to a contact channel during an incident.
-
#activate_contact_channel(params = {}) ⇒ Struct
Activates a contact's contact channel.
-
#create_contact(params = {}) ⇒ Types::CreateContactResult
Contacts are either the contacts that Incident Manager engages during an incident or the escalation plans that Incident Manager uses to engage contacts in phases during an incident.
-
#create_contact_channel(params = {}) ⇒ Types::CreateContactChannelResult
A contact channel is the method that Incident Manager uses to engage your contact.
-
#create_rotation(params = {}) ⇒ Types::CreateRotationResult
Creates a rotation in an on-call schedule.
-
#create_rotation_override(params = {}) ⇒ Types::CreateRotationOverrideResult
Creates an override for a rotation in an on-call schedule.
-
#deactivate_contact_channel(params = {}) ⇒ Struct
To no longer receive Incident Manager engagements to a contact channel, you can deactivate the channel.
-
#delete_contact(params = {}) ⇒ Struct
To remove a contact from Incident Manager, you can delete the contact.
-
#delete_contact_channel(params = {}) ⇒ Struct
To stop receiving engagements on a contact channel, you can delete the channel from a contact.
-
#delete_rotation(params = {}) ⇒ Struct
Deletes a rotation from the system.
-
#delete_rotation_override(params = {}) ⇒ Struct
Deletes an existing override for an on-call rotation.
-
#describe_engagement(params = {}) ⇒ Types::DescribeEngagementResult
Incident Manager uses engagements to engage contacts and escalation plans during an incident.
-
#describe_page(params = {}) ⇒ Types::DescribePageResult
Lists details of the engagement to a contact channel.
-
#get_contact(params = {}) ⇒ Types::GetContactResult
Retrieves information about the specified contact or escalation plan.
-
#get_contact_channel(params = {}) ⇒ Types::GetContactChannelResult
List details about a specific contact channel.
-
#get_contact_policy(params = {}) ⇒ Types::GetContactPolicyResult
Retrieves the resource policies attached to the specified contact or escalation plan.
-
#get_rotation(params = {}) ⇒ Types::GetRotationResult
Retrieves information about an on-call rotation.
-
#get_rotation_override(params = {}) ⇒ Types::GetRotationOverrideResult
Retrieves information about an override to an on-call rotation.
-
#list_contact_channels(params = {}) ⇒ Types::ListContactChannelsResult
Lists all contact channels for the specified contact.
-
#list_contacts(params = {}) ⇒ Types::ListContactsResult
Lists all contacts and escalation plans in Incident Manager.
-
#list_engagements(params = {}) ⇒ Types::ListEngagementsResult
Lists all engagements that have happened in an incident.
-
#list_page_receipts(params = {}) ⇒ Types::ListPageReceiptsResult
Lists all of the engagements to contact channels that have been acknowledged.
-
#list_page_resolutions(params = {}) ⇒ Types::ListPageResolutionsResult
Returns the resolution path of an engagement.
-
#list_pages_by_contact(params = {}) ⇒ Types::ListPagesByContactResult
Lists the engagements to a contact's contact channels.
-
#list_pages_by_engagement(params = {}) ⇒ Types::ListPagesByEngagementResult
Lists the engagements to contact channels that occurred by engaging a contact.
-
#list_preview_rotation_shifts(params = {}) ⇒ Types::ListPreviewRotationShiftsResult
Returns a list of shifts based on rotation configuration parameters.
-
#list_rotation_overrides(params = {}) ⇒ Types::ListRotationOverridesResult
Retrieves a list of overrides currently specified for an on-call rotation.
-
#list_rotation_shifts(params = {}) ⇒ Types::ListRotationShiftsResult
Returns a list of shifts generated by an existing rotation in the system.
-
#list_rotations(params = {}) ⇒ Types::ListRotationsResult
Retrieves a list of on-call rotations.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Lists the tags of a contact, escalation plan, rotation, or on-call schedule.
-
#put_contact_policy(params = {}) ⇒ Struct
Adds a resource policy to the specified contact or escalation plan.
-
#send_activation_code(params = {}) ⇒ Struct
Sends an activation code to a contact channel.
-
#start_engagement(params = {}) ⇒ Types::StartEngagementResult
Starts an engagement to a contact or escalation plan.
-
#stop_engagement(params = {}) ⇒ Struct
Stops an engagement before it finishes the final stage of the escalation plan or engagement plan.
-
#tag_resource(params = {}) ⇒ Struct
Tags a contact or escalation plan.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_contact(params = {}) ⇒ Struct
Updates the contact or escalation plan specified.
-
#update_contact_channel(params = {}) ⇒ Struct
Updates a contact's contact channel.
-
#update_rotation(params = {}) ⇒ Struct
Updates the information specified for an on-call rotation.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-ssmcontacts/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2472 2473 2474 |
# File 'lib/aws-sdk-ssmcontacts/client.rb', line 2472 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2475 2476 2477 |
# File 'lib/aws-sdk-ssmcontacts/client.rb', line 2475 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_page(params = {}) ⇒ Struct
Used to acknowledge an engagement to a contact channel during an incident.
86 |
# File 'sig/client.rbs', line 86
def accept_page: (
|
#activate_contact_channel(params = {}) ⇒ Struct
Activates a contact's contact channel. Incident Manager can't engage a contact until the contact channel has been activated.
100 |
# File 'sig/client.rbs', line 100
def activate_contact_channel: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 |
# File 'lib/aws-sdk-ssmcontacts/client.rb', line 2445 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SSMContacts') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ssmcontacts' context[:gem_version] = '1.64.0' Seahorse::Client::Request.new(handlers, context) end |
#create_contact(params = {}) ⇒ Types::CreateContactResult
Contacts are either the contacts that Incident Manager engages during an incident or the escalation plans that Incident Manager uses to engage contacts in phases during an incident.
111 |
# File 'sig/client.rbs', line 111
def create_contact: (
|
#create_contact_channel(params = {}) ⇒ Types::CreateContactChannelResult
A contact channel is the method that Incident Manager uses to engage your contact.
131 |
# File 'sig/client.rbs', line 131
def create_contact_channel: (
|
#create_rotation(params = {}) ⇒ Types::CreateRotationResult
Creates a rotation in an on-call schedule.
148 |
# File 'sig/client.rbs', line 148
def create_rotation: (
|
#create_rotation_override(params = {}) ⇒ Types::CreateRotationOverrideResult
Creates an override for a rotation in an on-call schedule.
169 |
# File 'sig/client.rbs', line 169
def create_rotation_override: (
|
#deactivate_contact_channel(params = {}) ⇒ Struct
To no longer receive Incident Manager engagements to a contact channel, you can deactivate the channel.
182 |
# File 'sig/client.rbs', line 182
def deactivate_contact_channel: (
|
#delete_contact(params = {}) ⇒ Struct
To remove a contact from Incident Manager, you can delete the contact. However, deleting a contact does not remove it from escalation plans and related response plans. Deleting an escalation plan also does not remove it from all related response plans. To modify an escalation plan, we recommend using the UpdateContact action to specify a different existing contact.
191 |
# File 'sig/client.rbs', line 191
def delete_contact: (
|
#delete_contact_channel(params = {}) ⇒ Struct
To stop receiving engagements on a contact channel, you can delete the channel from a contact. Deleting the contact channel does not remove it from the contact's engagement plan, but the stage that includes the channel will be ignored. If you delete the only contact channel for a contact, you'll no longer be able to engage that contact during an incident.
200 |
# File 'sig/client.rbs', line 200
def delete_contact_channel: (
|
#delete_rotation(params = {}) ⇒ Struct
Deletes a rotation from the system. If a rotation belongs to more than one on-call schedule, this operation deletes it from all of them.
209 |
# File 'sig/client.rbs', line 209
def delete_rotation: (
|
#delete_rotation_override(params = {}) ⇒ Struct
Deletes an existing override for an on-call rotation.
218 |
# File 'sig/client.rbs', line 218
def delete_rotation_override: (
|
#describe_engagement(params = {}) ⇒ Types::DescribeEngagementResult
Incident Manager uses engagements to engage contacts and escalation plans during an incident. Use this command to describe the engagement that occurred during an incident.
238 |
# File 'sig/client.rbs', line 238
def describe_engagement: (
|
#describe_page(params = {}) ⇒ Types::DescribePageResult
Lists details of the engagement to a contact channel.
259 |
# File 'sig/client.rbs', line 259
def describe_page: (
|
#get_contact(params = {}) ⇒ Types::GetContactResult
Retrieves information about the specified contact or escalation plan.
273 |
# File 'sig/client.rbs', line 273
def get_contact: (
|
#get_contact_channel(params = {}) ⇒ Types::GetContactChannelResult
List details about a specific contact channel.
288 |
# File 'sig/client.rbs', line 288
def get_contact_channel: (
|
#get_contact_policy(params = {}) ⇒ Types::GetContactPolicyResult
Retrieves the resource policies attached to the specified contact or escalation plan.
299 |
# File 'sig/client.rbs', line 299
def get_contact_policy: (
|
#get_rotation(params = {}) ⇒ Types::GetRotationResult
Retrieves information about an on-call rotation.
314 |
# File 'sig/client.rbs', line 314
def get_rotation: (
|
#get_rotation_override(params = {}) ⇒ Types::GetRotationOverrideResult
Retrieves information about an override to an on-call rotation.
329 |
# File 'sig/client.rbs', line 329
def get_rotation_override: (
|
#list_contact_channels(params = {}) ⇒ Types::ListContactChannelsResult
Lists all contact channels for the specified contact.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
341 |
# File 'sig/client.rbs', line 341
def list_contact_channels: (
|
#list_contacts(params = {}) ⇒ Types::ListContactsResult
Lists all contacts and escalation plans in Incident Manager.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
354 |
# File 'sig/client.rbs', line 354
def list_contacts: (
|
#list_engagements(params = {}) ⇒ Types::ListEngagementsResult
Lists all engagements that have happened in an incident.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
368 |
# File 'sig/client.rbs', line 368
def list_engagements: (
|
#list_page_receipts(params = {}) ⇒ Types::ListPageReceiptsResult
Lists all of the engagements to contact channels that have been acknowledged.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
385 |
# File 'sig/client.rbs', line 385
def list_page_receipts: (
|
#list_page_resolutions(params = {}) ⇒ Types::ListPageResolutionsResult
Returns the resolution path of an engagement. For example, the escalation plan engaged in an incident might target an on-call schedule that includes several contacts in a rotation, but just one contact on-call when the incident starts. The resolution path indicates the hierarchy of escalation plan > on-call schedule > contact.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
398 |
# File 'sig/client.rbs', line 398
def list_page_resolutions: (
|
#list_pages_by_contact(params = {}) ⇒ Types::ListPagesByContactResult
Lists the engagements to a contact's contact channels.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
410 |
# File 'sig/client.rbs', line 410
def list_pages_by_contact: (
|
#list_pages_by_engagement(params = {}) ⇒ Types::ListPagesByEngagementResult
Lists the engagements to contact channels that occurred by engaging a contact.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
423 |
# File 'sig/client.rbs', line 423
def list_pages_by_engagement: (
|
#list_preview_rotation_shifts(params = {}) ⇒ Types::ListPreviewRotationShiftsResult
Returns a list of shifts based on rotation configuration parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
436 |
# File 'sig/client.rbs', line 436
def list_preview_rotation_shifts: (
|
#list_rotation_overrides(params = {}) ⇒ Types::ListRotationOverridesResult
Retrieves a list of overrides currently specified for an on-call rotation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
461 |
# File 'sig/client.rbs', line 461
def list_rotation_overrides: (
|
#list_rotation_shifts(params = {}) ⇒ Types::ListRotationShiftsResult
Returns a list of shifts generated by an existing rotation in the system.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
476 |
# File 'sig/client.rbs', line 476
def list_rotation_shifts: (
|
#list_rotations(params = {}) ⇒ Types::ListRotationsResult
Retrieves a list of on-call rotations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
491 |
# File 'sig/client.rbs', line 491
def list_rotations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Lists the tags of a contact, escalation plan, rotation, or on-call schedule.
503 |
# File 'sig/client.rbs', line 503
def list_tags_for_resource: (
|
#put_contact_policy(params = {}) ⇒ Struct
Adds a resource policy to the specified contact or escalation plan. The resource policy is used to share the contact or escalation plan using Resource Access Manager (RAM). For more information about cross-account sharing, see Setting up cross-account functionality.
512 |
# File 'sig/client.rbs', line 512
def put_contact_policy: (
|
#send_activation_code(params = {}) ⇒ Struct
Sends an activation code to a contact channel. The contact can use
this code to activate the contact channel in the console or with the
ActivateChannel operation. Incident Manager can't engage a contact
channel until it has been activated.
522 |
# File 'sig/client.rbs', line 522
def send_activation_code: (
|
#start_engagement(params = {}) ⇒ Types::StartEngagementResult
Starts an engagement to a contact or escalation plan. The engagement engages each contact specified in the incident.
532 |
# File 'sig/client.rbs', line 532
def start_engagement: (
|
#stop_engagement(params = {}) ⇒ Struct
Stops an engagement before it finishes the final stage of the escalation plan or engagement plan. Further contacts aren't engaged.
548 |
# File 'sig/client.rbs', line 548
def stop_engagement: (
|
#tag_resource(params = {}) ⇒ Struct
Tags a contact or escalation plan. You can tag only contacts and escalation plans in the first region of your replication set.
558 |
# File 'sig/client.rbs', line 558
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
573 |
# File 'sig/client.rbs', line 573
def untag_resource: (
|
#update_contact(params = {}) ⇒ Struct
Updates the contact or escalation plan specified.
583 |
# File 'sig/client.rbs', line 583
def update_contact: (
|
#update_contact_channel(params = {}) ⇒ Struct
Updates a contact's contact channel.
594 |
# File 'sig/client.rbs', line 594
def update_contact_channel: (
|
#update_rotation(params = {}) ⇒ Struct
Updates the information specified for an on-call rotation.
607 |
# File 'sig/client.rbs', line 607
def update_rotation: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2465 2466 2467 |
# File 'lib/aws-sdk-ssmcontacts/client.rb', line 2465 def waiter_names [] end |