Class: Aws::SSMContacts::Types::Contact
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSMContacts::Types::Contact
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssmcontacts/types.rb
Overview
A personal contact or escalation plan that Incident Manager engages during an incident.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The unique and identifiable alias of the contact or escalation plan.
-
#contact_arn ⇒ String
The Amazon Resource Name (ARN) of the contact or escalation plan.
-
#display_name ⇒ String
The full name of the contact or escalation plan.
-
#type ⇒ String
The type of contact.
Instance Attribute Details
#alias ⇒ String
The unique and identifiable alias of the contact or escalation plan.
177 178 179 180 181 182 183 184 |
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 177 class Contact < Struct.new( :contact_arn, :alias, :display_name, :type) SENSITIVE = [] include Aws::Structure end |
#contact_arn ⇒ String
The Amazon Resource Name (ARN) of the contact or escalation plan.
177 178 179 180 181 182 183 184 |
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 177 class Contact < Struct.new( :contact_arn, :alias, :display_name, :type) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The full name of the contact or escalation plan.
177 178 179 180 181 182 183 184 |
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 177 class Contact < Struct.new( :contact_arn, :alias, :display_name, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of contact.
-
‘PERSONAL`: A single, individual contact.
-
‘ESCALATION`: An escalation plan.
-
‘ONCALL_SCHEDULE`: An on-call schedule.
177 178 179 180 181 182 183 184 |
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 177 class Contact < Struct.new( :contact_arn, :alias, :display_name, :type) SENSITIVE = [] include Aws::Structure end |