Class: Aws::SSMContacts::Types::CreateContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmcontacts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

The short name to quickly identify a contact or escalation plan. The contact alias must be unique and identifiable.



406
407
408
409
410
411
412
413
414
415
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 406

class CreateContactRequest < Struct.new(
  :alias,
  :display_name,
  :type,
  :plan,
  :tags,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The full name of the contact or escalation plan.



406
407
408
409
410
411
412
413
414
415
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 406

class CreateContactRequest < Struct.new(
  :alias,
  :display_name,
  :type,
  :plan,
  :tags,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#idempotency_tokenString

A token ensuring that the operation is called only once with the specified details.

**A suitable default value is auto-generated.** You should normally not need to pass this option.



406
407
408
409
410
411
412
413
414
415
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 406

class CreateContactRequest < Struct.new(
  :alias,
  :display_name,
  :type,
  :plan,
  :tags,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#planTypes::Plan

A list of stages. A contact has an engagement plan with stages that contact specified contact channels. An escalation plan uses stages that contact specified contacts.



406
407
408
409
410
411
412
413
414
415
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 406

class CreateContactRequest < Struct.new(
  :alias,
  :display_name,
  :type,
  :plan,
  :tags,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Adds a tag to the target. You can only tag resources created in the first Region of your replication set.



406
407
408
409
410
411
412
413
414
415
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 406

class CreateContactRequest < Struct.new(
  :alias,
  :display_name,
  :type,
  :plan,
  :tags,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of contact to create.

  • PERSONAL: A single, individual contact.

  • ESCALATION: An escalation plan.

  • ONCALL_SCHEDULE: An on-call schedule.



406
407
408
409
410
411
412
413
414
415
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 406

class CreateContactRequest < Struct.new(
  :alias,
  :display_name,
  :type,
  :plan,
  :tags,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end