Class: Aws::SSMContacts::Types::CreateRotationOverrideRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmcontacts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

The date and time when the override ends.



458
459
460
461
462
463
464
465
466
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 458

class CreateRotationOverrideRequest < Struct.new(
  :rotation_id,
  :new_contact_ids,
  :start_time,
  :end_time,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#idempotency_tokenString

A token that ensures that the operation is called only once with the specified details.



458
459
460
461
462
463
464
465
466
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 458

class CreateRotationOverrideRequest < Struct.new(
  :rotation_id,
  :new_contact_ids,
  :start_time,
  :end_time,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#new_contact_idsArray<String>

The Amazon Resource Names (ARNs) of the contacts to replace those in the current on-call rotation with.

If you want to include any current team members in the override shift, you must include their ARNs in the new contact ID list.



458
459
460
461
462
463
464
465
466
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 458

class CreateRotationOverrideRequest < Struct.new(
  :rotation_id,
  :new_contact_ids,
  :start_time,
  :end_time,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#rotation_idString

The Amazon Resource Name (ARN) of the rotation to create an override for.



458
459
460
461
462
463
464
465
466
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 458

class CreateRotationOverrideRequest < Struct.new(
  :rotation_id,
  :new_contact_ids,
  :start_time,
  :end_time,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The date and time when the override goes into effect.



458
459
460
461
462
463
464
465
466
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 458

class CreateRotationOverrideRequest < Struct.new(
  :rotation_id,
  :new_contact_ids,
  :start_time,
  :end_time,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end