Class: Aws::SSMContacts::Types::DescribeEngagementResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmcontacts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_arn ⇒ String

The ARN of the escalation plan or contacts involved in the engagement.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 750

class DescribeEngagementResult < Struct.new(
  :contact_arn,
  :engagement_arn,
  :sender,
  :subject,
  :content,
  :public_subject,
  :public_content,
  :incident_id,
  :start_time,
  :stop_time)
  SENSITIVE = []
  include Aws::Structure
end

#content ⇒ String

The secure content of the message that was sent to the contact. Use this field for engagements to VOICE and EMAIL.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 750

class DescribeEngagementResult < Struct.new(
  :contact_arn,
  :engagement_arn,
  :sender,
  :subject,
  :content,
  :public_subject,
  :public_content,
  :incident_id,
  :start_time,
  :stop_time)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_arn ⇒ String

The ARN of the engagement.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 750

class DescribeEngagementResult < Struct.new(
  :contact_arn,
  :engagement_arn,
  :sender,
  :subject,
  :content,
  :public_subject,
  :public_content,
  :incident_id,
  :start_time,
  :stop_time)
  SENSITIVE = []
  include Aws::Structure
end

#incident_id ⇒ String

The ARN of the incident in which the engagement occurred.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 750

class DescribeEngagementResult < Struct.new(
  :contact_arn,
  :engagement_arn,
  :sender,
  :subject,
  :content,
  :public_subject,
  :public_content,
  :incident_id,
  :start_time,
  :stop_time)
  SENSITIVE = []
  include Aws::Structure
end

#public_content ⇒ String

The insecure content of the message that was sent to the contact. Use this field for engagements to SMS.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 750

class DescribeEngagementResult < Struct.new(
  :contact_arn,
  :engagement_arn,
  :sender,
  :subject,
  :content,
  :public_subject,
  :public_content,
  :incident_id,
  :start_time,
  :stop_time)
  SENSITIVE = []
  include Aws::Structure
end

#public_subject ⇒ String

The insecure subject of the message that was sent to the contact. Use this field for engagements to SMS.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 750

class DescribeEngagementResult < Struct.new(
  :contact_arn,
  :engagement_arn,
  :sender,
  :subject,
  :content,
  :public_subject,
  :public_content,
  :incident_id,
  :start_time,
  :stop_time)
  SENSITIVE = []
  include Aws::Structure
end

#sender ⇒ String

The user that started the engagement.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 750

class DescribeEngagementResult < Struct.new(
  :contact_arn,
  :engagement_arn,
  :sender,
  :subject,
  :content,
  :public_subject,
  :public_content,
  :incident_id,
  :start_time,
  :stop_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ Time

The time that the engagement started.

Returns:

  • (Time)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 750

class DescribeEngagementResult < Struct.new(
  :contact_arn,
  :engagement_arn,
  :sender,
  :subject,
  :content,
  :public_subject,
  :public_content,
  :incident_id,
  :start_time,
  :stop_time)
  SENSITIVE = []
  include Aws::Structure
end

#stop_time ⇒ Time

The time that the engagement ended.

Returns:

  • (Time)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 750

class DescribeEngagementResult < Struct.new(
  :contact_arn,
  :engagement_arn,
  :sender,
  :subject,
  :content,
  :public_subject,
  :public_content,
  :incident_id,
  :start_time,
  :stop_time)
  SENSITIVE = []
  include Aws::Structure
end

#subject ⇒ String

The secure subject of the message that was sent to the contact. Use this field for engagements to VOICE and EMAIL.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 750

class DescribeEngagementResult < Struct.new(
  :contact_arn,
  :engagement_arn,
  :sender,
  :subject,
  :content,
  :public_subject,
  :public_content,
  :incident_id,
  :start_time,
  :stop_time)
  SENSITIVE = []
  include Aws::Structure
end