Class: Aws::SSMContacts::Types::ListContactChannelsResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmcontacts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_channels ⇒ Array<Types::ContactChannel>

A list of contact channels related to the specified contact.

Returns:



1199
1200
1201
1202
1203
1204
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1199

class ListContactChannelsResult < Struct.new(
  :next_token,
  :contact_channels)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token to continue to the next page of results.

Returns:

  • (String)


1199
1200
1201
1202
1203
1204
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1199

class ListContactChannelsResult < Struct.new(
  :next_token,
  :contact_channels)
  SENSITIVE = []
  include Aws::Structure
end