Class: Aws::SSMContacts::Types::ListContactsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmcontacts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alias_prefixString

Used to list only contacts who’s aliases start with the specified prefix.

Returns:

  • (String)


1226
1227
1228
1229
1230
1231
1232
1233
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1226

class ListContactsRequest < Struct.new(
  :next_token,
  :max_results,
  :alias_prefix,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of contacts and escalation plans per page of results.

Returns:

  • (Integer)


1226
1227
1228
1229
1230
1231
1232
1233
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1226

class ListContactsRequest < Struct.new(
  :next_token,
  :max_results,
  :alias_prefix,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to continue to the next page of results.

Returns:

  • (String)


1226
1227
1228
1229
1230
1231
1232
1233
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1226

class ListContactsRequest < Struct.new(
  :next_token,
  :max_results,
  :alias_prefix,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of contact.

Returns:

  • (String)


1226
1227
1228
1229
1230
1231
1232
1233
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1226

class ListContactsRequest < Struct.new(
  :next_token,
  :max_results,
  :alias_prefix,
  :type)
  SENSITIVE = []
  include Aws::Structure
end