Class: Aws::SSMContacts::Types::ListPreviewRotationShiftsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmcontacts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_time ⇒ Time

The date and time a rotation shift would end.

Returns:

  • (Time)


1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1503

class ListPreviewRotationShiftsRequest < Struct.new(
  :rotation_start_time,
  :start_time,
  :end_time,
  :members,
  :time_zone_id,
  :recurrence,
  :overrides,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return for this call. The call also returns a token that can be specified in a subsequent call to get the next set of results.

Returns:

  • (Integer)


1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1503

class ListPreviewRotationShiftsRequest < Struct.new(
  :rotation_start_time,
  :start_time,
  :end_time,
  :members,
  :time_zone_id,
  :recurrence,
  :overrides,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#members ⇒ Array<String>

The contacts that would be assigned to a rotation.

Returns:

  • (Array<String>)


1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1503

class ListPreviewRotationShiftsRequest < Struct.new(
  :rotation_start_time,
  :start_time,
  :end_time,
  :members,
  :time_zone_id,
  :recurrence,
  :overrides,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token to start the list. This token is used to get the next set of results.

Returns:

  • (String)


1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1503

class ListPreviewRotationShiftsRequest < Struct.new(
  :rotation_start_time,
  :start_time,
  :end_time,
  :members,
  :time_zone_id,
  :recurrence,
  :overrides,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#overrides ⇒ Array<Types::PreviewOverride>

Information about changes that would be made in a rotation override.

Returns:



1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1503

class ListPreviewRotationShiftsRequest < Struct.new(
  :rotation_start_time,
  :start_time,
  :end_time,
  :members,
  :time_zone_id,
  :recurrence,
  :overrides,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#recurrence ⇒ Types::RecurrenceSettings

Information about how long a rotation would last before restarting at the beginning of the shift order.



1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1503

class ListPreviewRotationShiftsRequest < Struct.new(
  :rotation_start_time,
  :start_time,
  :end_time,
  :members,
  :time_zone_id,
  :recurrence,
  :overrides,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#rotation_start_time ⇒ Time

The date and time a rotation would begin. The first shift is calculated from this date and time.

Returns:

  • (Time)


1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1503

class ListPreviewRotationShiftsRequest < Struct.new(
  :rotation_start_time,
  :start_time,
  :end_time,
  :members,
  :time_zone_id,
  :recurrence,
  :overrides,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ Time

Used to filter the range of calculated shifts before sending the response back to the user.

Returns:

  • (Time)


1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1503

class ListPreviewRotationShiftsRequest < Struct.new(
  :rotation_start_time,
  :start_time,
  :end_time,
  :members,
  :time_zone_id,
  :recurrence,
  :overrides,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#time_zone_id ⇒ String

The time zone the rotation’s activity would be based on, in Internet Assigned Numbers Authority (IANA) format. For example: "America/Los_Angeles", "UTC", or "Asia/Seoul".

Returns:

  • (String)


1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1503

class ListPreviewRotationShiftsRequest < Struct.new(
  :rotation_start_time,
  :start_time,
  :end_time,
  :members,
  :time_zone_id,
  :recurrence,
  :overrides,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end