Class: Aws::SSMContacts::Types::ListRotationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmcontacts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.



1665
1666
1667
1668
1669
1670
1671
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1665

class ListRotationsRequest < Struct.new(
  :rotation_name_prefix,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to start the list. Use this token to get the next set of results.



1665
1666
1667
1668
1669
1670
1671
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1665

class ListRotationsRequest < Struct.new(
  :rotation_name_prefix,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#rotation_name_prefixString

A filter to include rotations in list results based on their common prefix. For example, entering prod returns a list of all rotation names that begin with prod, such as production and prod-1.



1665
1666
1667
1668
1669
1670
1671
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1665

class ListRotationsRequest < Struct.new(
  :rotation_name_prefix,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end