Class: Aws::SSMContacts::Types::ListRotationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSMContacts::Types::ListRotationsResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssmcontacts/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for the next set of items to return.
-
#rotations ⇒ Array<Types::Rotation>
Information about rotations that meet the filter criteria.
Instance Attribute Details
#next_token ⇒ String
The token for the next set of items to return. Use this token to get the next set of results.
1684 1685 1686 1687 1688 1689 |
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1684 class ListRotationsResult < Struct.new( :next_token, :rotations) SENSITIVE = [] include Aws::Structure end |
#rotations ⇒ Array<Types::Rotation>
Information about rotations that meet the filter criteria.
1684 1685 1686 1687 1688 1689 |
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 1684 class ListRotationsResult < Struct.new( :next_token, :rotations) SENSITIVE = [] include Aws::Structure end |