Class: Aws::SSMContacts::Types::Target
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSMContacts::Types::Target
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssmcontacts/types.rb
Overview
The contact or contact channel that’s being engaged.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_target_info ⇒ Types::ChannelTargetInfo
Information about the contact channel that Incident Manager engages.
-
#contact_target_info ⇒ Types::ContactTargetInfo
Information about the contact that Incident Manager engages.
Instance Attribute Details
#channel_target_info ⇒ Types::ChannelTargetInfo
Information about the contact channel that Incident Manager engages.
2325 2326 2327 2328 2329 2330 |
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 2325 class Target < Struct.new( :channel_target_info, :contact_target_info) SENSITIVE = [] include Aws::Structure end |
#contact_target_info ⇒ Types::ContactTargetInfo
Information about the contact that Incident Manager engages.
2325 2326 2327 2328 2329 2330 |
# File 'lib/aws-sdk-ssmcontacts/types.rb', line 2325 class Target < Struct.new( :channel_target_info, :contact_target_info) SENSITIVE = [] include Aws::Structure end |